@@ -6,9 +6,9 @@ testthat::test_that("mutate_db works on databases", {
 
   ## Input table with clean names
   ## Let's get some matches, amazing how bad this is.  Need wikidata synonyms
-  taxa <- taxa_tbl("itis") %>%
+  taxa <- taxa_tbl("itis_test") %>%
     mutate_db(clean_names, "scientificName", "input")
-
+  expect_is(taxa, "tbl")
 
 })
 
